@@ -59,7 +59,7 @@ SKGDashboardPluginWidget::SKGDashboardPluginWidget(QWidget* iParent, SKGDocument
     // Drag and drop
     m_clickedPoint = QPoint(-1, -1);
 
-    ui.kTitle->setPixmap(QApplication::windowIcon().pixmap(22, 22), KTitleWidget::ImageLeft);
+    ui.kTitle->setIcon(QApplication::windowIcon(), KTitleWidget::ImageLeft);
     ui.kTitle->setComment("<html><body><b>" % i18nc("Message", "Welcome to %1", KAboutData::applicationData().displayName()) % "</b></body></html>");
 
     // Build menu
