@@ -425,7 +425,7 @@ void SKGFilePlugin::onOpen(const QUrl& iUrl)
 
                     // Get password
                     if (useKWallet) {
-                        SKGTRACEL(10) << "Use KWallet" << Qt::endl;
+                        SKGTRACEL(10) << "Use KWallet" << SKGENDL;
                         // Use KWallet
                         QString walletName = skgfile_settings::selectedWallet();
                         if (!KWallet::Wallet::walletList().contains(walletName)) {
@@ -445,7 +445,7 @@ void SKGFilePlugin::onOpen(const QUrl& iUrl)
                             // Read password
                             w->readPassword(fileName, pwd);
                             if (pwd.isEmpty()) {
-                                SKGTRACEL(10) << "Password not found in KWallet for " << fileName << Qt::endl;
+                                SKGTRACEL(10) << "Password not found in KWallet for " << fileName << SKGENDL;
                                 useKWallet = false;
                             }
 
@@ -455,7 +455,7 @@ void SKGFilePlugin::onOpen(const QUrl& iUrl)
                     }
 
                     if (!useKWallet) {
-                        SKGTRACEL(10) << "Ask password" << Qt::endl;
+                        SKGTRACEL(10) << "Ask password" << SKGENDL;
                         // Use password dialog
                         QPointer<KPasswordDialog> dlg = new KPasswordDialog(SKGMainPanel::getMainPanel());
                         dlg->setPrompt(additionalMessage % i18nc("Question", "This file seems to be protected.\nPlease enter the password."));
