@@ -26,24 +26,51 @@
 #include "skgdocument.h"
 #include "skgmainpanel.h"
 #include "skgtraces.h"
+#include "skgreport.h"
 
 #include <QMetaProperty>
 
 #include <KFormat>
 
+QString fixSQL(SKGReport* report, const QString& iSql)
+{
+    auto sql = iSql;
+    sql = sql.replace("##PERIOD##", SKGServices::getPeriodWhereClause(report->getPeriod()));
+    sql = sql.replace("##<PERIOD##", SKGServices::getPeriodWhereClause(report->getPeriod(), QStringLiteral("d_date"), QStringLiteral("<")));
+    sql = sql.replace("##>PERIOD##", SKGServices::getPeriodWhereClause(report->getPeriod(), QStringLiteral("d_date"), QStringLiteral(">")));
+    sql = sql.replace("##<=PERIOD##", SKGServices::getPeriodWhereClause(report->getPeriod(), QStringLiteral("d_date"), QStringLiteral("<=")));
+    sql = sql.replace("##>=PERIOD##", SKGServices::getPeriodWhereClause(report->getPeriod(), QStringLiteral("d_date"), QStringLiteral(">=")));
+
+    sql = sql.replace("##PREVIOUS_PERIOD##", SKGServices::getPeriodWhereClause(report->getPreviousPeriod()));
+    sql = sql.replace("##<PREVIOUS_PERIOD##", SKGServices::getPeriodWhereClause(report->getPreviousPeriod(), QStringLiteral("d_date"), QStringLiteral("<")));
+    sql = sql.replace("##>PREVIOUS_PERIOD##", SKGServices::getPeriodWhereClause(report->getPreviousPeriod(), QStringLiteral("d_date"), QStringLiteral(">")));
+    sql = sql.replace("##<=PREVIOUS_PERIOD##", SKGServices::getPeriodWhereClause(report->getPreviousPeriod(), QStringLiteral("d_date"), QStringLiteral("<=")));
+    sql = sql.replace("##>=PREVIOUS_PERIOD##", SKGServices::getPeriodWhereClause(report->getPreviousPeriod(), QStringLiteral("d_date"), QStringLiteral(">=")));
+    return sql;
+}
+
 QVariant SKGDocumentTableFilter::doFilter(const QVariant& input, const QVariant& argument, bool autoescape) const
 {
     Q_UNUSED(autoescape)
+    SKGReport* report = nullptr;
     auto* doc = qobject_cast< SKGDocument* >(input.value<QObject*>());
+    if (doc == nullptr) {
+        report = qobject_cast< SKGReport* >(input.value<QObject*>());
+        doc = report->getDocument();
+    }
     if ((doc != nullptr) && argument.isValid()) {
         SKGObjectBase::SKGListSKGObjectBase objects;
         QString table = Grantlee::getSafeString(argument);
         QString wc;
-        int pos = table.indexOf(QStringLiteral(","));
+        int pos = table.lastIndexOf(QStringLiteral(","));
         if (pos != -1) {
             wc = table.right(table.count() - pos - 1);
             table = table.left(pos);
         }
+        if (report != nullptr) {
+            table = fixSQL(report, table);
+            wc = fixSQL(report, wc);
+        }
 
         doc->getObjects(table, wc, objects);
         return QVariant::fromValue(objects);
@@ -60,9 +87,17 @@ bool SKGDocumentTableFilter::isSafe() const
 QVariant SKGDocumentQueryFilter::doFilter(const QVariant& input, const QVariant& argument, bool autoescape) const
 {
     Q_UNUSED(autoescape)
+    SKGReport* report = nullptr;
     auto* doc = qobject_cast< SKGDocument* >(input.value<QObject*>());
+    if (doc == nullptr) {
+        report = qobject_cast< SKGReport* >(input.value<QObject*>());
+        doc = report->getDocument();
+    }
     if ((doc != nullptr) && argument.isValid()) {
         QString sql = Grantlee::getSafeString(argument);
+        if (report != nullptr) {
+            sql = fixSQL(report, sql);
+        }
         SKGStringListList result;
         doc->executeSelectSqliteOrder(sql, result);
         return QVariant::fromValue(result);
