@@ -70,7 +70,7 @@ bool SKGMonthlyPlugin::setupActions(SKGDocument* iDocument)
     QString writablePath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
     QString path = writablePath % QLatin1Char('/') + KAboutData::applicationData().componentName() % QStringLiteral("/html/default");
     if (!QDir(writablePath).mkpath(KAboutData::applicationData().componentName() % QStringLiteral("/html/default"))) {
-        SKGTRACE << "WARNING: Impossible to create  html/default in " << writablePath << Qt::endl;
+        SKGTRACE << "WARNING: Impossible to create  html/default in " << writablePath << SKGENDL;
     }
 
     // Copy "default" directory in locale
@@ -83,7 +83,7 @@ bool SKGMonthlyPlugin::setupActions(SKGDocument* iDocument)
             QString target = path % QLatin1Char('/') % QFileInfo(file).fileName();
             QFile(target).remove();
             if (file != target && !QFile(file).copy(target)) {
-                SKGTRACE << "WARNING: Impossible to copie " << file << " in " << target << Qt::endl;
+                SKGTRACE << "WARNING: Impossible to copie " << file << " in " << target << SKGENDL;
             }
         }
     }
