@@ -178,10 +178,10 @@ SKGError SKGPrintPlugin::getHtml(QPrinter* iPrinter, QString& oHtml) const
             toPage = fromPage;
         }
 
-        SKGTRACEL(10) << "Nb copy document=" << docCopies << Qt::endl;
-        SKGTRACEL(10) << "Nb copy page=" << docCopies << Qt::endl;
-        SKGTRACEL(10) << "From=" << fromPage << Qt::endl;
-        SKGTRACEL(10) << "To=" << toPage << Qt::endl;
+        SKGTRACEL(10) << "Nb copy document=" << docCopies << SKGENDL;
+        SKGTRACEL(10) << "Nb copy page=" << docCopies << SKGENDL;
+        SKGTRACEL(10) << "From=" << fromPage << SKGENDL;
+        SKGTRACEL(10) << "To=" << toPage << SKGENDL;
 
         // Copy document
         for (int c = 1; !err && c <= docCopies; ++c) {
