@@ -49,7 +49,7 @@ SKGPropertiesPlugin::SKGPropertiesPlugin(QWidget* iWidget, QObject* iParent, con
 
     // Get list of bills
     m_billsProcess.setStandardOutputFile(QDir::tempPath() % "/skg_bills.csv");
-    m_billsProcess.start(QStringLiteral("boobill bills  -q -f csv -v"));
+    m_billsProcess.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << QStringLiteral("boobill bills  -q -f csv -v"));
 
     connect(&m_billsProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &SKGPropertiesPlugin::onBillsRetreived);
     connect(&m_billsProcess, static_cast<void (QProcess::*)(QProcess::ProcessError)>(&QProcess::errorOccurred), this, &SKGPropertiesPlugin::onBillsRetreived);
@@ -186,7 +186,7 @@ void SKGPropertiesPlugin::onDownloadAndAddBills()
                 QFile::remove(fileName);
                 QString cmd = "boobill download " % id % " \"" % fileName % '"';
                 QProcess p;
-                p.start(cmd);
+                p.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
                 if (!p.waitForFinished(60000) || p.exitCode() != 0) {
                     err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed with code %2:\n'%1'", cmd, p.exitCode()));
                 } else {
