@@ -215,7 +215,7 @@ void SKGStatisticPlugin::triggerAction()
     auto* act = qobject_cast< QAction* >(sender());
     if (act != nullptr) {
         QString id = "nb_call." % act->objectName();
-        SKGTRACEL(10) << "SKGStatisticPlugin::triggerAction " << id << "++" << Qt::endl;
+        SKGTRACEL(10) << "SKGStatisticPlugin::triggerAction " << id << "++" << SKGENDL;
         m_stats[id] = m_stats[id].toInt() + 1;
     }
 }
