@@ -106,7 +106,7 @@ struct download {
         // Execute
         QProcess p;
         cmd = SKGServices::getFullPathCommandLine(cmd);
-        SKGTRACEL(10) << "Execute: " << cmd << Qt::endl;
+        SKGTRACEL(10) << "Execute: " << cmd << SKGENDL;
         p.setStandardOutputFile(file);
 
         int retry = 0;
@@ -116,10 +116,10 @@ struct download {
                 if (p.exitCode() == 0) {
                     return iAccountId;
                 }
-                SKGTRACE << i18nc("A warning message", "WARNING: The command %1 failed with code %2 (Retry %3)", cmd, p.exitCode(), retry + 1) << Qt::endl;
+                SKGTRACE << i18nc("A warning message", "WARNING: The command %1 failed with code %2 (Retry %3)", cmd, p.exitCode(), retry + 1) << SKGENDL;
 
             } else {
-                SKGTRACE << i18nc("A warning message", "WARNING: The command %1 failed due to a time out (Retry %2)", cmd, retry + 1) << Qt::endl;
+                SKGTRACE << i18nc("A warning message", "WARNING: The command %1 failed due to a time out (Retry %2)", cmd, retry + 1) << SKGENDL;
                 p.terminate();
                 p.kill();
             }
@@ -127,7 +127,7 @@ struct download {
         } while (retry < 6);
 
         QString errorMsg = i18nc("Error message",  "The following command line failed with code %2:\n'%1'", cmd, p.exitCode());
-        SKGTRACE << errorMsg << Qt::endl;
+        SKGTRACE << errorMsg << SKGENDL;
 
         return QStringLiteral("ERROR:") + errorMsg;
     }
@@ -162,7 +162,7 @@ SKGError SKGImportPluginBackend::importFile()
     QString cmd = getParameter(QStringLiteral("X-SKROOGE-getaccounts")).replace(QStringLiteral("%3"), pwd);
     QProcess p;
     cmd = SKGServices::getFullPathCommandLine(cmd);
-    SKGTRACEL(10) << "Execute: " << cmd << Qt::endl;
+    SKGTRACEL(10) << "Execute: " << cmd << SKGENDL;
     p.setStandardOutputFile(csvfile);
     p.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
     if (!p.waitForFinished(1000 * 60 * 2) || p.exitCode() != 0) {
@@ -182,7 +182,7 @@ SKGError SKGImportPluginBackend::importFile()
             while (!stream.atEnd()) {
                 // Read line
                 QString line = stream.readLine().trimmed();
-                SKGTRACEL(10) << "Read line: " << line << Qt::endl;
+                SKGTRACEL(10) << "Read line: " << line << SKGENDL;
 
                 // Get account id
                 int pos = reggetaccounts.indexIn(line);
@@ -250,28 +250,28 @@ SKGError SKGImportPluginBackend::importFile()
             QString cmddownload;
             if (!bulk.isEmpty()) {
                 // mode bulk
-                SKGTRACEL(10) << "Mode getbulk" << Qt::endl;
+                SKGTRACEL(10) << "Mode getbulk" << SKGENDL;
                 QProcess pbulk;
                 QString cmd = bulk.replace(QStringLiteral("%1"), m_tempDir.path());
                 cmd = SKGServices::getFullPathCommandLine(cmd);
                 cmddownload = cmd;
-                SKGTRACEL(10) << "Execute: " << cmd << Qt::endl;
+                SKGTRACEL(10) << "Execute: " << cmd << SKGENDL;
                 pbulk.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
                 if (!pbulk.waitForFinished(1000 * 60 * 2) || pbulk.exitCode() != 0) {
                     err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed with code %2:\n'%1'", cmd, pbulk.exitCode()));
                 } else {
-                    SKGTRACEL(10) << "Searching csv files " << Qt::endl;
+                    SKGTRACEL(10) << "Searching csv files " << SKGENDL;
                     QDirIterator it(m_tempDir.path(), QStringList() << QStringLiteral("*.csv"));
                     while (it.hasNext()) {
                         auto id = QFileInfo(it.next()).baseName();
                         listDownloadedId.push_back(id);
 
-                        SKGTRACEL(10) << "Find id: " << id << Qt::endl;
+                        SKGTRACEL(10) << "Find id: " << id << SKGENDL;
                     }
                 }
             } else {
                 // mode getoperations
-                SKGTRACEL(10) << "Mode getoperations" << Qt::endl;
+                SKGTRACEL(10) << "Mode getoperations" << SKGENDL;
                 cmddownload = getParameter(QStringLiteral("X-SKROOGE-getoperations"));
                 QFuture<QString> f = QtConcurrent::mapped(backendAccounts, download(nbToDownload, fromDate, cmddownload, pwd, m_tempDir.path()));
                 f.waitForFinished();
@@ -302,7 +302,7 @@ SKGError SKGImportPluginBackend::importFile()
                         // Warning
                         m_importer->getDocument()->sendMessage(i18nc("Warning message", "Some accounts have not been downloaded. %1", errors.join(QStringLiteral(". "))), SKGDocument::Warning);
                     }
-                    SKGTRACEL(10) << errors.count() << " accounts not imported => checkOK=false" << Qt::endl;
+                    SKGTRACEL(10) << errors.count() << " accounts not imported => checkOK=false" << SKGENDL;
                     checkOK = false;
                 }
 
@@ -386,7 +386,7 @@ SKGError SKGImportPluginBackend::importFile()
                         auto targetBalance = accountsToCheck[i].second;
                         auto soluces = act.getPossibleReconciliations(targetBalance, false);
                         if (soluces.isEmpty()) {
-                            SKGTRACEL(10) << "Account " << listDownloadedId.at(i) << " not reconciliable => checkOK=false" << Qt::endl;
+                            SKGTRACEL(10) << "Account " << listDownloadedId.at(i) << " not reconciliable => checkOK=false" << SKGENDL;
                             checkOK = false;
                         }
                     }
