@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
+ *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -711,7 +711,7 @@ SKGError SKGImportPluginCsv::importFile()
                             }
                         }
                         if (!err && idgroup != 0) {
-                            if (mapGroup.contains(idgroup)) {
+                            if (mapGroup.contains(idgroup) && currentOperation != mapGroup[idgroup]) {
                                 err = currentOperation.setGroupOperation(mapGroup[idgroup]);
                                 IFOKDO(err, currentOperation.save())
                             }
