@@ -443,7 +443,9 @@ SKGError SKGImportPluginGnc::importFile()
                                     IFOKDO(err, operationObj.save())
 
                                     IFOKDO(err, suboperationObj.setAttribute(QStringLiteral("d_date"), QStringLiteral("0000-00-00")))
-                                    IFOKDO(err, suboperationObj.save())
+                                    if (suboperationObj.getDocument() != nullptr) {
+                                        IFOKDO(err, suboperationObj.save())
+                                    }
                                 } else if (accountType == 'A') {
                                     // It is a transfer of account
                                     SKGAccountObject act(m_importer->getDocument());
