@@ -382,7 +382,7 @@ SKGError SKGImportPluginIif::exportFile()
                                << '\t' << act.getComment()
                                << '\t' << act.getAgencyNumber()
                                << '\t'
-                               << Qt::endl;
+                               << SKGENDL;
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -407,7 +407,7 @@ SKGError SKGImportPluginIif::exportFile()
                                << '\t'
                                << '\t'
                                << '\t'
-                               << Qt::endl;
+                               << SKGENDL;
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -428,7 +428,7 @@ SKGError SKGImportPluginIif::exportFile()
                     stream << "CUST"
                            << '\t' << payee.getName()
                            << '\t' << payee.getAddress()
-                           << Qt::endl;
+                           << SKGENDL;
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
@@ -462,7 +462,7 @@ SKGError SKGImportPluginIif::exportFile()
                                << '\t' << op.getNumber()
                                << '\t' << (op.getStatus() == SKGOperationObject::CHECKED ? QStringLiteral("Y") : QStringLiteral("N"))
                                << '\t' << op.getComment()
-                               << Qt::endl;
+                               << SKGENDL;
 
                         // Export sub operations
                         SKGObjectBase::SKGListSKGObjectBase sops;
@@ -483,10 +483,10 @@ SKGError SKGImportPluginIif::exportFile()
                                    << '\t' << op.getNumber()
                                    << '\t' << (op.getStatus() == SKGOperationObject::CHECKED ? QStringLiteral("Y") : QStringLiteral("N"))
                                    << '\t' << sop.getComment()
-                                   << Qt::endl;
+                                   << SKGENDL;
                         }
                     }
-                    stream << "ENDTRNS" << Qt::endl;
+                    stream << "ENDTRNS" << SKGENDL;
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
 
