@@ -65,7 +65,7 @@ SKGError SKGImportPluginJson::exportFile()
             if (!m_importer->getCodec().isEmpty()) {
                 stream.setCodec(m_importer->getCodec().toLatin1().constData());
             }
-            stream << doc << Qt::endl;
+            stream << doc << SKGENDL;
 
             // Close file
             file.commit();
