@@ -952,7 +952,7 @@ SKGError SKGImportPluginKmy::exportSecurities(QDomDocument& doc, QDomElement& ro
                 SKGUnitValueObject unitval(unitValues.at(j));
                 price.setAttribute(QStringLiteral("price"), SKGImportPluginKmy::kmyValue(unitval.getQuantity()));
                 price.setAttribute(QStringLiteral("source"), QStringLiteral("Utilisateur"));
-                price.setAttribute(QStringLiteral("date"), SKGServices::dateToSqlString(unitval.getDate().startOfDay()));
+                price.setAttribute(QStringLiteral("date"), SKGServices::dateToSqlString(unitval.getDate()));
             }
 
             IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
