@@ -29,6 +29,7 @@
 #include <qdom.h>
 #include <qprocess.h>
 #include <qdir.h>
+#include <quuid.h>
 
 #include "skgbankincludes.h"
 #include "skgdocumentbank.h"
@@ -93,7 +94,7 @@ SKGError SKGImportPluginLedger::exportFile()
         if (!m_importer->getCodec().isEmpty()) {
             stream.setCodec(m_importer->getCodec().toLatin1().constData());
         }
-        stream << "; -*- ledger file generated by Skrooge -*-" << Qt::endl;
+        stream << "; -*- ledger file generated by Skrooge -*-" << SKGENDL;
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export %1 file", "ledger"), 2);
         IFOK(err) {
             auto punit = m_importer->getDocument()->getPrimaryUnit();
@@ -108,8 +109,8 @@ SKGError SKGImportPluginLedger::exportFile()
                     stream << "P " << SKGServices::dateToSqlString(QDate::currentDate()).replace('-', '/')
                            << " \"" << unit.getSymbol() << '"'
                            << " " << qs
-                           << Qt::endl;
-                    stream << Qt::endl;
+                           << SKGENDL;
+                    stream << SKGENDL;
 
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -162,16 +163,16 @@ SKGError SKGImportPluginLedger::exportFile()
                            << (status == SKGOperationObject::CHECKED ? " *" : status == SKGOperationObject::POINTED ? " !" : "")
                            << (!number.isEmpty() ? QStringLiteral(" (") % number % ")" : QString())
                            << QStringLiteral(" ") << payeeString
-                           << Qt::endl;
-                    stream << "  ; Skrooge ID: " << op.getID() << Qt::endl;
-                    stream << "  ; Import ID: " << op.getImportID() << Qt::endl;
+                           << SKGENDL;
+                    stream << "  ; Skrooge ID: " << op.getID() << SKGENDL;
+                    stream << "  ; Import ID: " << op.getImportID() << SKGENDL;
                     auto properties = op.getProperties();
                     for (const auto& p : qAsConst(properties)) {
-                        stream << "  ; " << p << ": " << op.getProperty(p) << Qt::endl;
+                        stream << "  ; " << p << ": " << op.getProperty(p) << SKGENDL;
                     }
                     stream << "  " << i18nc("The default category for the accounts for ledger export", "Account") << ':' << op.getAttribute(QStringLiteral("t_ACCOUNT"))
                            << "  " << qs
-                           << Qt::endl;
+                           << SKGENDL;
 
                     SKGObjectBase::SKGListSKGObjectBase suboperations;
                     IFOKDO(err, op.getSubOperations(suboperations))
@@ -202,9 +203,9 @@ SKGError SKGImportPluginLedger::exportFile()
                             stream << "  ;comment=" << comment;
                         }
                         stream << "  ; Skrooge ID: " << sop.getID();
-                        stream << Qt::endl;
+                        stream << SKGENDL;
                     }
-                    stream << Qt::endl;
+                    stream << SKGENDL;
 
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -247,7 +248,7 @@ SKGError SKGImportPluginLedger::importFile()
     QString uniqueId = QUuid::createUuid().toString();
     QString temporaryPath = QDir::tempPath() % "/" % uniqueId % ".xml";
     QString cmd = "ledger -f \"" % m_importer->getLocalFileName() % "\" xml --output " % temporaryPath;
-    SKGTRACEL(10) << "Execution of :" << cmd << Qt::endl;
+    SKGTRACEL(10) << "Execution of :" << cmd << SKGENDL;
     QProcess p;
     p.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
     if (p.waitForFinished(1000 * 60 * 5) && p.exitCode() == 0) {
@@ -372,7 +373,7 @@ SKGError SKGImportPluginLedger::importFile()
                                 type = names[0].toUpper();
                                 name = name.right(name.length() - type.length() - 1);
                             }
-                            SKGTRACEL(2) << "Sub transaction : " << name << ": " << date << ": " << payee << " | " << quantity << Qt::endl;
+                            SKGTRACEL(2) << "Sub transaction : " << name << ": " << date << ": " << payee << " | " << quantity << SKGENDL;
 
                             auto isaccount = isAccount(type);
                             if (i2 > 0) {
