@@ -160,7 +160,7 @@ SKGError SKGImportPluginMny::importFile()
     QDir temporaryDir(temporaryPath);
 
     QString cmd = "java -cp \"" % sunriise_jar % "\" com/le/sunriise/export/ExportToJSON \"" % m_importer->getLocalFileName() % "\" \"" % m_importParameters.value(QStringLiteral("password")) % "\" " % temporaryPath;
-    SKGTRACEL(10) << "Execution of :" << cmd << Qt::endl;
+    SKGTRACEL(10) << "Execution of :" << cmd << SKGENDL;
     QProcess p;
     p.start(QStringLiteral("/bin/bash"), QStringList() << QStringLiteral("-c") << cmd);
     if (p.waitForFinished(1000 * 60 * 5) && p.exitCode() == 0) {
