@@ -160,7 +160,7 @@ QString SKGImportPluginOfx::getAccountName(OfxAccountData* iAccountData)
             }
         }
     }
-    SKGTRACEL(3) << "accountNumber=" << accountNumber << Qt::endl;
+    SKGTRACEL(3) << "accountNumber=" << accountNumber << SKGENDL;
     return accountNumber;
 }
 
@@ -172,10 +172,10 @@ SKGError SKGImportPluginOfx::getAccount(OfxAccountData* iAccountData, SKGDocumen
         // Check if account is already existing
         QString name = getAccountName(iAccountData);
         if (m_accounts.contains(name)) {
-            SKGTRACEL(3) << "Found in index" << Qt::endl;
+            SKGTRACEL(3) << "Found in index" << SKGENDL;
             oAccount = m_accounts[name];
         } else {
-            SKGTRACEL(3) << "NOT found in index" << Qt::endl;
+            SKGTRACEL(3) << "NOT found in index" << SKGENDL;
             QString wc = "t_number='" % SKGServices::stringToSqlString(name) % "' OR EXISTS(SELECT 1 FROM parameters WHERE t_uuid_parent=v_account.id||'-account' AND t_name='alias' AND t_value= '" % SKGServices::stringToSqlString(name) % "')";
             err = iDoc->getObject(QStringLiteral("v_account"), wc, oAccount);
         }
@@ -339,14 +339,14 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
         if (!SKGImportPluginOfx::m_ofxError) {
             SKGImportPluginOfx::m_ofxError = account.save();
             m_accounts[accountNumber] = account;
-            SKGTRACEL(3) << "Add account '" << accountNumber << "' in index" << Qt::endl;
+            SKGTRACEL(3) << "Add account '" << accountNumber << "' in index" << SKGENDL;
         }
 
         if (!SKGImportPluginOfx::m_ofxError) {
             SKGImportPluginOfx::m_ofxError = impotExporter->setDefaultAccount(&account);
         }
 
-        SKGTRACEL(10) << "Account [" << name << "] created" << Qt::endl;
+        SKGTRACEL(10) << "Account [" << name << "] created" << SKGENDL;
     }
 
     if (static_cast<bool>(data.currency_valid)) {
