@@ -169,7 +169,7 @@ SKGError SKGImportPluginPDF::importFile()
                                 if (!d.isValid()) {
                                     d = QDate::fromString(date);
                                     if (!d.isValid()) {
-                                        SKGTRACE << "WARNING: Impossible to parse the date [" << date << "] with [" << dateFormat << "]" << Qt::endl;
+                                        SKGTRACE << "WARNING: Impossible to parse the date [" << date << "] with [" << dateFormat << "]" << SKGENDL;
                                     }
                                 }
                                 if (!dateFormat.contains(QStringLiteral("yyyy")) && d.year() < 2000) {
