@@ -785,8 +785,8 @@ SKGError SKGImportPluginQif::importFile()
                                     QString wc = "t_ACCOUNT='" % SKGServices::stringToSqlString(ta) %
                                                  "' AND t_TOACCOUNT='" % SKGServices::stringToSqlString(accountOrigin.getName()) %
                                                  "' AND ABS(f_QUANTITY-(" % SKGServices::doubleToString(-qua) % "))<0.0001"
-                                                 " AND ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(opOrigin.getDate().startOfDay()) % "'))<1"
-                                                 " ORDER BY ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(opOrigin.getDate().startOfDay()) % "')) ASC";
+                                                 " AND ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(opOrigin.getDate()) % "'))<1"
+                                                 " ORDER BY ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(opOrigin.getDate()) % "')) ASC";
                                     SKGObjectBase::SKGListSKGObjectBase obs;
                                     m_importer->getDocument()->getObjects(QStringLiteral("v_operation_display"), wc, obs);
                                     if (!obs.isEmpty()) {
@@ -813,8 +813,8 @@ SKGError SKGImportPluginQif::importFile()
                                         // Is the operation already created as a transfer of an other one?
                                         QString wc = "t_import_id='QIF TRANSFER-" % SKGServices::stringToSqlString(ta) % "' AND t_ACCOUNT='" % SKGServices::stringToSqlString(accountOrigin.getName()) %
                                                      "' AND (ABS(f_CURRENTAMOUNT-(" % SKGServices::doubleToString(opOrigin.getCurrentAmount()) % "))<0.0001 OR f_QUANTITY=" % SKGServices::doubleToString(qua) % ")"
-                                                     " AND ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(opOrigin.getDate().startOfDay()) % "'))<1"
-                                                     " ORDER BY ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(opOrigin.getDate().startOfDay()) % "')) ASC";
+                                                     " AND ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(opOrigin.getDate()) % "'))<1"
+                                                     " ORDER BY ABS(julianday(d_date) - julianday('" % SKGServices::dateToSqlString(opOrigin.getDate()) % "')) ASC";
                                         m_importer->getDocument()->getObjects(QStringLiteral("v_operation_display"), wc, obs);
                                         if (!obs.isEmpty()) {
                                             // We have to merge them and we do not need to create the transfer
@@ -988,13 +988,13 @@ SKGError SKGImportPluginQif::exportFile()
                     SKGCategoryObject cat(categories.at(i));
                     QString catName = cat.getFullName();
                     if (!catName.isEmpty()) {
-                        stream << QStringLiteral("N") << catName.replace(OBJECTSEPARATOR, QStringLiteral(":")) << Qt::endl;
+                        stream << QStringLiteral("N") << catName.replace(OBJECTSEPARATOR, QStringLiteral(":")) << SKGENDL;
                         if (SKGServices::stringToDouble(cat.getAttribute(QStringLiteral("f_REALCURRENTAMOUNT"))) < 0) {
-                            stream << "E" << Qt::endl;
+                            stream << "E" << SKGENDL;
                         } else {
-                            stream << "I" << Qt::endl;
+                            stream << "I" << SKGENDL;
                         }
-                        stream << "^" << Qt::endl;
+                        stream << "^" << SKGENDL;
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -1032,9 +1032,9 @@ SKGError SKGImportPluginQif::exportFile()
 
                             // Write header
                             stream << "!Account\n";
-                            stream << 'N' << accountName << Qt::endl;
+                            stream << 'N' << accountName << SKGENDL;
                             QString type = (account.getType() == SKGAccountObject::CURRENT ? QStringLiteral("Bank") : (account.getType() == SKGAccountObject::CREDITCARD ? QStringLiteral("CCard") : (account.getType() == SKGAccountObject::INVESTMENT ? QStringLiteral("Invst") : (account.getType() == SKGAccountObject::ASSETS ? QStringLiteral("Oth A") : QStringLiteral("Cash")))));
-                            stream << 'T' << type << Qt::endl;
+                            stream << 'T' << type << SKGENDL;
                             QString number = bank.getNumber();
                             QString bnumber = account.getAgencyNumber();
                             QString cnumber = account.getNumber();
@@ -1050,10 +1050,10 @@ SKGError SKGImportPluginQif::exportFile()
                                 }
                                 number += cnumber;
                             }
-                            stream << 'D' << number << Qt::endl;
+                            stream << 'D' << number << SKGENDL;
                             // stream << "/"      Statement balance date
                             // stream << "$"      Statement balance amount
-                            stream << '^' << Qt::endl;
+                            stream << '^' << SKGENDL;
                             currentAccountName = accountName;
 
                             stream << "!Type:" << type << "\n";
@@ -1095,27 +1095,27 @@ SKGError SKGImportPluginQif::exportFile()
                             investment = true;
                         }
 
-                        QString date = SKGServices::dateToSqlString(operation.getDate().startOfDay());
+                        QString date = SKGServices::dateToSqlString(operation.getDate());
                         if (date.isEmpty()) {
                             // This is an opening balance
                             date = QStringLiteral("0000-00-00");
                         }
-                        stream << 'D' << date << Qt::endl;
+                        stream << 'D' << date << SKGENDL;
                         if (!unitExported) {
-                            stream << 'T' << SKGServices::doubleToString(operation.getCurrentAmount()) << Qt::endl;
+                            stream << 'T' << SKGServices::doubleToString(operation.getCurrentAmount()) << SKGENDL;
                         }
 
                         if (!investment) {
                             auto number = operation.getNumber();
                             if (!number.isEmpty()) {
-                                stream << 'N' << operation.getNumber() << Qt::endl;
+                                stream << 'N' << operation.getNumber() << SKGENDL;
                             }
                         } else {
-                            stream << 'N' << (operation.getCurrentAmount() > 0 ? "Buy" : "Sell") << Qt::endl;
+                            stream << 'N' << (operation.getCurrentAmount() > 0 ? "Buy" : "Sell") << SKGENDL;
                         }
 
                         if (unitExported) {
-                            stream << 'Y' << unit.getSymbol() << Qt::endl;
+                            stream << 'Y' << unit.getSymbol() << SKGENDL;
                         }
 
                         SKGPayeeObject payeeObj;
@@ -1126,20 +1126,20 @@ SKGError SKGImportPluginQif::exportFile()
                             payee = OPENINGBALANCE;
                         }
                         if (!payee.isEmpty()) {
-                            stream << 'P' << payee << Qt::endl;
+                            stream << 'P' << payee << SKGENDL;
                         }
                         if (!address.isEmpty()) {
-                            stream << 'A' << address << Qt::endl;
+                            stream << 'A' << address << SKGENDL;
                         }
 
                         QString memo = operation.getMode() % "  " % operation.getComment();
                         memo = memo.trimmed();
                         if (!memo.isEmpty()) {
-                            stream << 'M' << memo << Qt::endl;
+                            stream << 'M' << memo << SKGENDL;
                         }
 
                         SKGOperationObject::OperationStatus status = operation.getStatus();
-                        stream << 'C' << (status == SKGOperationObject::POINTED ? "C" : (status == SKGOperationObject::CHECKED ? "R" : "")) << Qt::endl;
+                        stream << 'C' << (status == SKGOperationObject::POINTED ? "C" : (status == SKGOperationObject::CHECKED ? "R" : "")) << SKGENDL;
 
                         // Get sub operations
                         SKGObjectBase::SKGListSKGObjectBase suboperations;
@@ -1151,8 +1151,8 @@ SKGError SKGImportPluginQif::exportFile()
                                 SKGSubOperationObject suboperation(suboperations.at(0));
                                 // Dump quantity
                                 if (unitExported) {
-                                    stream << 'Q' << SKGServices::doubleToString(qAbs(suboperation.getQuantity())) << Qt::endl;
-                                    stream << 'I' << SKGServices::doubleToString(qAbs(operation.getCurrentAmount() / suboperation.getQuantity())) << Qt::endl;
+                                    stream << 'Q' << SKGServices::doubleToString(qAbs(suboperation.getQuantity())) << SKGENDL;
+                                    stream << 'I' << SKGServices::doubleToString(qAbs(operation.getCurrentAmount() / suboperation.getQuantity())) << SKGENDL;
                                 }
 
                                 // Get category of this simple operation
@@ -1173,7 +1173,7 @@ SKGError SKGImportPluginQif::exportFile()
                                 IFOK(err) category.prepend('[' % transferAccount.getName() % ']');
                             }
                             if (!category.isEmpty()) {
-                                stream << 'L' << category << Qt::endl;
+                                stream << 'L' << category << SKGENDL;
                             }
 
                             if (nbSubOps > 1) {
@@ -1185,19 +1185,19 @@ SKGError SKGImportPluginQif::exportFile()
 
                                     QString category2 = cat.getFullName().replace(OBJECTSEPARATOR, QStringLiteral(":"));
                                     if (!category2.isEmpty()) {
-                                        stream << 'S' << category2 << Qt::endl;
+                                        stream << 'S' << category2 << SKGENDL;
                                     }
                                     QString memo2 = suboperation.getComment();
                                     memo2 = memo2.trimmed();
                                     if (!memo2.isEmpty()) {
-                                        stream << 'E' << memo2 << Qt::endl;
+                                        stream << 'E' << memo2 << SKGENDL;
                                     }
-                                    stream << '$' << SKGServices::doubleToString(suboperation.getQuantity()) << Qt::endl;
+                                    stream << '$' << SKGServices::doubleToString(suboperation.getQuantity()) << SKGENDL;
                                 }
                             }
                         }
 
-                        stream << '^' << Qt::endl;
+                        stream << '^' << SKGENDL;
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
@@ -1225,13 +1225,13 @@ SKGError SKGImportPluginQif::exportFile()
                         }
                         vals.push_back(v);
                         vals.push_back(SKGServices::doubleToString(unitVal.getQuantity()));
-                        vals.push_back(SKGServices::dateToSqlString(unitVal.getDate().startOfDay()));
+                        vals.push_back(SKGServices::dateToSqlString(unitVal.getDate()));
 
-                        stream << SKGServices::stringsToCsv(vals) << Qt::endl;
+                        stream << SKGServices::stringsToCsv(vals) << SKGENDL;
                     }
                     IFOKDO(err, m_importer->getDocument()->stepForward(i + 1))
                 }
-                stream << "^" << Qt::endl;
+                stream << "^" << SKGENDL;
 
                 SKGENDTRANSACTION(m_importer->getDocument(),  err)
             }
