@@ -26,6 +26,12 @@
 #include <klocalizedstring.h>
 #include <kmessagebox.h>
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+#define SKGENDL endl
+#else
+#define SKGENDL Qt::endl
+#endif
+
 SKGAddOperation::SKGAddOperation(QObject* iParent, const QVariantList& args)
     : AbstractRunner(iParent, args)
 {
@@ -77,16 +83,16 @@ void SKGAddOperation::run(const Plasma::RunnerContext& iContext, const Plasma::Q
     QSaveFile file(fileName);
     if (file.open(QIODevice::WriteOnly)) {
         QTextStream stream(&file);
-        stream << "buy" << Qt::endl;
-        stream << QDate::currentDate().toString(QStringLiteral("yyyy-MM-dd")) << Qt::endl;
+        stream << "buy" << SKGENDL;
+        stream << QDate::currentDate().toString(QStringLiteral("yyyy-MM-dd")) << SKGENDL;
         QString s = iMatch.id().remove(0, QStringLiteral("skroogeaddoperation_").length());
         int pos = s.indexOf(QStringLiteral(" "));
         if (pos == -1) {
-            stream << s << Qt::endl;
-            stream << "" << Qt::endl;
+            stream << s << SKGENDL;
+            stream << "" << SKGENDL;
         } else {
-            stream << s.left(pos).trimmed() << Qt::endl;
-            stream << s.right(s.length() - pos - 1).trimmed() << Qt::endl;
+            stream << s.left(pos).trimmed() << SKGENDL;
+            stream << s.right(s.length() - pos - 1).trimmed() << SKGENDL;
         }
 
         // Close file
