@@ -60,9 +60,6 @@ public:
      */
     void reloadConfiguration() override;
 
-protected Q_SLOTS:
-    void init() override;
-
 private:
     QString m_triggerWord;
 };
