@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
+ *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -169,7 +169,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
     connect(ui.kView->getView(), &SKGTreeView::selectionChangedDelayed, this, [ = ] {this->onSelectionChanged();});
 
     // Search file list
-    QString listIconFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/images/logo/l10n/" % QLocale::countryToString(QLocale().country()) % "/list_bank.txt");
+    QString listIconFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "skrooge/images/logo/l10n/" % QLocale().name().split("_").at(0) % "/list_bank.txt");
     if (listIconFile.isEmpty()) {
         listIconFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/images/logo/list_bank.txt"));
     }
