@@ -54,13 +54,13 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(QWidget* iParent, SKGDocume
     ui.kUpdate->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
     ui.kAdd->setIcon(SKGServices::fromTheme(QStringLiteral("list-add")));
 
-    ui.kLoadSummaryTitle->setPixmap(SKGServices::fromTheme(QStringLiteral("configure")).pixmap(22, 22), KTitleWidget::ImageLeft);
-    ui.kPaymentSummaryTitle->setPixmap(SKGServices::fromTheme(QStringLiteral("bookmarks")).pixmap(22, 22), KTitleWidget::ImageLeft);
-    ui.kAmortizationTableTitle->setPixmap(SKGServices::fromTheme(QStringLiteral("view-pim-calendar")).pixmap(22, 22), KTitleWidget::ImageLeft);
+    ui.kLoadSummaryTitle->setIcon(SKGServices::fromTheme(QStringLiteral("configure")), KTitleWidget::ImageLeft);
+    ui.kPaymentSummaryTitle->setIcon(SKGServices::fromTheme(QStringLiteral("bookmarks")), KTitleWidget::ImageLeft);
+    ui.kAmortizationTableTitle->setIcon(SKGServices::fromTheme(QStringLiteral("view-pim-calendar")), KTitleWidget::ImageLeft);
 
-    ui.kInterestResultsTitle->setPixmap(SKGServices::fromTheme(QStringLiteral("bookmarks")).pixmap(22, 22), KTitleWidget::ImageLeft);
-    ui.kInterestValuesTitle->setPixmap(SKGServices::fromTheme(QStringLiteral("configure")).pixmap(22, 22), KTitleWidget::ImageLeft);
-    ui.kDefineValueTitle->setPixmap(SKGServices::fromTheme(QStringLiteral("configure")).pixmap(22, 22), KTitleWidget::ImageLeft);
+    ui.kInterestResultsTitle->setIcon(SKGServices::fromTheme(QStringLiteral("bookmarks")), KTitleWidget::ImageLeft);
+    ui.kInterestValuesTitle->setIcon(SKGServices::fromTheme(QStringLiteral("configure")), KTitleWidget::ImageLeft);
+    ui.kDefineValueTitle->setIcon(SKGServices::fromTheme(QStringLiteral("configure")), KTitleWidget::ImageLeft);
 
     ui.kCreditValueDate->addItem(i18nc("A period of 15 days",  "Fifteen"));
     ui.kDebitValueDate->addItem(i18nc("A period of 15 days",  "Fifteen"));
