@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
+ *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -85,7 +85,7 @@ bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument)
     connect(actImportStdCat, &QAction::triggered, this, &SKGCategoriesPlugin::importStandardCategories);
     registerGlobalAction(QStringLiteral("import_standard_categories"), actImportStdCat);
 
-    const auto dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "skrooge/categories/" % QLocale::countryToString(QLocale().country()), QStandardPaths::LocateDirectory);
+    const auto dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "skrooge/categories/" % QLocale().name().split("_").at(0), QStandardPaths::LocateDirectory);
     for (const auto& dir : dirs) {
         QDirIterator it(dir, QStringList() << QStringLiteral("*.qif"));
         while (it.hasNext()) {
