@@ -547,6 +547,10 @@ void SKGImportExportPlugin::importFiles(const QList<QUrl>& iFiles, int mode, boo
                             parameters[QStringLiteral("date_format")] = QString();
                         }
 
+                        imp1.setImportParameters(parameters);
+                    } else if (QFileInfo(fileName.path()).suffix().toUpper() == QStringLiteral("LEDGER")) {
+                        QMap<QString, QString> parameters = imp1.getImportParameters();
+                        parameters[QStringLiteral("ledger_account_identification")] = skgimportexport_settings::ledger_account_identification();
                         imp1.setImportParameters(parameters);
                     }
 
