@@ -1,6 +1,6 @@
 
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
+ *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -258,10 +258,14 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument)
     registerGlobalAction(QStringLiteral("view_open_operation_with_date_not_aligned"), actTmp);
 
     // ------------
-    auto actCleanAlignComment = new QAction(SKGServices::fromTheme(QStringLiteral("draw-freehand"), overlayrun), i18nc("Verb", "Align comment of suboperations of all operations"), this);
+    auto actCleanAlignComment = new QAction(SKGServices::fromTheme(QStringLiteral("draw-freehand"), overlayrun), i18nc("Verb", "Align comment of suboperations of all single operations"), this);
     connect(actCleanAlignComment, &QAction::triggered, this, &SKGOperationPlugin::onAlignComment);
     registerGlobalAction(QStringLiteral("clean_align_comment"), actCleanAlignComment);
 
+    auto actCleanAlignComment2 = new QAction(SKGServices::fromTheme(QStringLiteral("draw-freehand"), overlayrun), i18nc("Verb", "Align comment of operations of all single operations"), this);
+    connect(actCleanAlignComment2, &QAction::triggered, this, &SKGOperationPlugin::onAlignComment2);
+    registerGlobalAction(QStringLiteral("clean_align_comment2"), actCleanAlignComment2);
+
     // ------------
     auto actCleanAlignDate = new QAction(SKGServices::fromTheme(QStringLiteral("view-pim-calendar"), overlayrun), i18nc("Verb", "Align date of suboperations of all operations"), this);
     connect(actCleanAlignDate, &QAction::triggered, this, &SKGOperationPlugin::onAlignDate);
@@ -361,11 +365,15 @@ void SKGOperationPlugin::refresh()
         bool onOperation = (nb > 0 && selection.at(0).getRealTable() == QStringLiteral("operation"));
 
         QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("clean_align_date"));
-        act->setText(onOperation ? i18nc("Verb", "Align date of suboperations of selected operations") : i18nc("Verb", "Align date of suboperations of all operations"));
+        act->setText(onOperation ? i18nc("Verb", "Align date of suboperations of selected single operations") : i18nc("Verb", "Align date of suboperations of all single operations"));
+        act->setData(onOperation);
+
+        act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("clean_align_comment2"));
+        act->setText(onOperation ? i18nc("Verb", "Align comment of operations of selected single operations") : i18nc("Verb", "Align comment of operations of all single operations"));
         act->setData(onOperation);
 
         act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("clean_align_comment"));
-        act->setText(onOperation ? i18nc("Verb", "Align comment of suboperations of selected operations") : i18nc("Verb", "Align comment of suboperations of all operations"));
+        act->setText(onOperation ? i18nc("Verb", "Align comment of suboperations of selected single operations") : i18nc("Verb", "Align comment of suboperations of all single operations"));
         act->setData(onOperation);
 
         act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("clean_remove_group_with_one_operation"));
@@ -871,7 +879,7 @@ void SKGOperationPlugin::onOpenOperations()
                 wc += ')';
 
                 // Set icon
-                iconOpen = QStringLiteral("checkbox");
+                iconOpen = QStringLiteral("crosshairs");
                 view = QStringLiteral("v_suboperation_consolidated");
             } else if (table == QStringLiteral("payee")) {
                 // Build whereclause and title
@@ -1426,6 +1434,12 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
                     a.IsRecommended = true;
                     autoCorrections.push_back(a);
                 }
+                {
+                    SKGAdvice::SKGAdviceAction a;
+                    a.Title = QStringLiteral("skg://clean_align_comment2");
+                    a.IsRecommended = false;
+                    autoCorrections.push_back(a);
+                }
                 ad.setAutoCorrections(autoCorrections);
 
                 mutex.lock();
@@ -1576,6 +1590,41 @@ void SKGOperationPlugin::onAlignComment()
     SKGMainPanel::displayErrorMessage(err);
 }
 
+void SKGOperationPlugin::onAlignComment2()
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(10, err)
+
+    {
+        SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
+        auto* act = qobject_cast< QAction* >(sender());
+        if ((act == nullptr) || !act->data().toBool()) {
+            // Clear selection to enable the model "All"
+            selection.clear();
+        }
+        SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Align comment of operations"), err)
+        QString q = QStringLiteral("UPDATE operation SET t_comment=(SELECT suboperation.t_comment FROM suboperation WHERE suboperation.rd_operation_id=operation.id) WHERE operation.id IN (SELECT operation.id FROM operation op, suboperation so WHERE so.rd_operation_id=op.id AND so.t_comment<>op.t_comment AND (SELECT COUNT(1) FROM suboperation so2 WHERE so2.rd_operation_id=op.id)=1)");
+        int nb = selection.count();
+        if (nb == 0) {
+            err = m_currentBankDocument->executeSqliteOrder(q);
+        } else {
+            for (int i = 0; !err && i < nb; ++i) {
+                SKGOperationObject op(selection.at(i));
+                err = m_currentBankDocument->executeSqliteOrder(q % " AND id=" % SKGServices::intToString(op.getID()));
+            }
+        }
+    }
+
+    // status bar
+    IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Comments aligned.")))
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Comments alignment failed"));
+    }
+
+    // Display error
+    SKGMainPanel::displayErrorMessage(err);
+}
+
 void SKGOperationPlugin::onAlignDate()
 {
     SKGError err;
