@@ -940,7 +940,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
 
             QString ParametersUsed = getState() % ';' % SKGServices::intToString(doc->getTransactionToProcess(SKGDocument::UNDO));
             if (ParametersUsed == m_previousParametersUsed) {
-                SKGTRACEL(10) << "Same parameters. Refresh ignored" << Qt::endl;
+                SKGTRACEL(10) << "Same parameters. Refresh ignored" << SKGENDL;
                 return;
             }
 
@@ -1002,7 +1002,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                         SKGObjectBase::SKGListSKGObjectBase budgets;
                         IFOKDO(err, doc->getObjects(QStringLiteral("v_budget"),
                                                     "t_PERIOD>STRFTIME('%Y-%m', date('now')) AND "
-                                                    "t_PERIOD<=STRFTIME('%Y-%m', '" % SKGServices::dateToSqlString(lastDate.startOfDay()) % "')", budgets));
+                                                    "t_PERIOD<=STRFTIME('%Y-%m', '" % SKGServices::dateToSqlString(lastDate) % "')", budgets));
                         int nbBudgets = budgets.count();
                         if (nbBudgets != 0) {
                             // Get most active account
@@ -1055,7 +1055,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                             }
                         }
                     }
-                    ui.kForecastValue->setToolTip(SKGServices::dateToSqlString(lastDate.startOfDay()));
+                    ui.kForecastValue->setToolTip(SKGServices::dateToSqlString(lastDate));
                 } else {
                     ui.kForecastValue->setToolTip(QLatin1String(""));
                     conditionForecast = QStringLiteral("1=0");
@@ -1139,7 +1139,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     QStringList dump = SKGServices::tableToDump(table, SKGServices::DUMP_TEXT);
                     int nbl = dump.count();
                     for (int i = 0; i < nbl; ++i) {
-                        SKGTRACE << dump.at(i) << Qt::endl;
+                        SKGTRACE << dump.at(i) << SKGENDL;
                     }
                 }
 
