@@ -76,7 +76,7 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(QWidget* iParent, SKGDocument
 
     ui.kJumpBtn->setIcon(SKGServices::fromTheme(QStringLiteral("quickopen")));
 
-    ui.kTitle->setPixmap(SKGServices::fromTheme(QStringLiteral("dialog-information")).pixmap(22, 22), KTitleWidget::ImageLeft);
+    ui.kTitle->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-information")), KTitleWidget::ImageLeft);
     bool exist = false;
     getDocument()->existObjects(QStringLiteral("recurrentoperation"), QLatin1String(""), exist);
     ui.kTitle->setVisible(!exist);
