@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
+ *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -83,7 +83,7 @@ QString SKGTrackerPlugin::title() const
 
 QString SKGTrackerPlugin::icon() const
 {
-    return QStringLiteral("checkbox");
+    return QStringLiteral("crosshairs");
 }
 
 QString SKGTrackerPlugin::toolTip() const
