@@ -344,7 +344,7 @@ QString SKGPredicatCreator::xmlDescription()
             if ((m_kValue1 != nullptr) && m_kValue1->isVisible()) {
                 auto* cmbVal1 = qobject_cast<SKGDateEdit*> (m_kValue1);
                 if (cmbVal1 != nullptr) {
-                    root.setAttribute(QStringLiteral("value"), SKGServices::dateToSqlString(cmbVal1->date().startOfDay()));
+                    root.setAttribute(QStringLiteral("value"), SKGServices::dateToSqlString(cmbVal1->date()));
                 } else {
                     auto* cmbVal12 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
                     if (cmbVal12 != nullptr) {
@@ -365,7 +365,7 @@ QString SKGPredicatCreator::xmlDescription()
             if ((m_kValue2 != nullptr) && m_kValue2->isVisible()) {
                 auto* cmbVal2 = qobject_cast<SKGDateEdit*> (m_kValue2);
                 if (cmbVal2 != nullptr) {
-                    root.setAttribute(QStringLiteral("value2"), SKGServices::dateToSqlString(cmbVal2->date().startOfDay()));
+                    root.setAttribute(QStringLiteral("value2"), SKGServices::dateToSqlString(cmbVal2->date()));
                 } else {
                     auto* cmbVal21 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
                     if (cmbVal21 != nullptr) {
