@@ -244,7 +244,7 @@ double SKGAccountObject::getAmount(QDate iDate, bool iOnlyCurrencies) const
     if (getDocument() != nullptr) {
         // Search result in cache
         QString ids = SKGServices::intToString(getID());
-        QString dates = SKGServices::dateToSqlString(iDate.startOfDay());
+        QString dates = SKGServices::dateToSqlString(iDate);
         QString key = "getamount-" % ids % '-' % dates;
         QString val = getDocument()->getCachedValue(key);
         if (val.isEmpty()) {
@@ -378,7 +378,7 @@ double SKGAccountObject::getMinLimitAmount() const
 
 SKGError SKGAccountObject::setReconciliationDate(QDate iDate)
 {
-    return setAttribute(QStringLiteral("d_reconciliationdate"), SKGServices::dateToSqlString(iDate.startOfDay()));
+    return setAttribute(QStringLiteral("d_reconciliationdate"), SKGServices::dateToSqlString(iDate));
 }
 
 QDate SKGAccountObject::getReconciliationDate() const
@@ -445,7 +445,7 @@ SKGError SKGAccountObject::getInterests(SKGListSKGObjectBase& oInterestList) con
 SKGError SKGAccountObject::getInterest(QDate iDate, SKGInterestObject& oInterest) const
 {
     QString ids = SKGServices::intToString(getID());
-    QString dates = SKGServices::dateToSqlString(iDate.startOfDay());
+    QString dates = SKGServices::dateToSqlString(iDate);
     SKGError err = SKGObjectBase::getDocument()->getObject(QStringLiteral("v_interest"),
                    "rd_account_id=" % ids % " AND d_date<='" % dates %
                    "' AND  ABS(strftime('%s','" % dates %
@@ -482,8 +482,8 @@ SKGError SKGAccountObject::getInterestItems(SKGAccountObject::SKGInterestItemLis
     SKGObjectBase::SKGListSKGObjectBase items;
     err = getDocument()->getObjects(QStringLiteral("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) %
                                     " AND t_template='N' AND t_TYPEUNIT IN ('1', '2', 'C')"
-                                    " AND d_date>='" % SKGServices::dateToSqlString(initialDate.startOfDay()) % "' "
-                                    " AND d_date<='" % SKGServices::dateToSqlString(lastDate.startOfDay()) % "' ORDER BY d_date", items);
+                                    " AND d_date>='" % SKGServices::dateToSqlString(initialDate) % "' "
+                                    " AND d_date<='" % SKGServices::dateToSqlString(lastDate) % "' ORDER BY d_date", items);
     int nb = items.count();
     for (int i = 0; !err && i < nb; ++i) {
         SKGOperationObject ob(items.at(i));
@@ -505,8 +505,8 @@ SKGError SKGAccountObject::getInterestItems(SKGAccountObject::SKGInterestItemLis
     // Add interest
     IFOK(err) {
         err = getDocument()->getObjects(QStringLiteral("v_interest"), "rd_account_id=" % SKGServices::intToString(getID()) %
-                                        " AND d_date>='" % SKGServices::dateToSqlString(initialDate.startOfDay()) % "' "
-                                        " AND d_date<='" % SKGServices::dateToSqlString(lastDate.startOfDay()) % "' ORDER BY d_date", items);
+                                        " AND d_date>='" % SKGServices::dateToSqlString(initialDate) % "' "
+                                        " AND d_date<='" % SKGServices::dateToSqlString(lastDate) % "' ORDER BY d_date", items);
 
         int pos = 0;
         int nb2 = items.count();
@@ -718,8 +718,8 @@ SKGError SKGAccountObject::computeInterestItems(SKGAccountObject::SKGInterestIte
             SKGObjectBase object = interest.object;
             QString sqlinsert =
                 "INSERT INTO interest_result (d_date,d_valuedate,t_comment,f_currentamount,f_coef,f_rate,f_annual_interest,f_accrued_interest) "
-                " VALUES ('" % SKGServices::dateToSqlString(interest.date.startOfDay()) %
-                "','" % SKGServices::dateToSqlString(interest.valueDate.startOfDay()) %
+                " VALUES ('" % SKGServices::dateToSqlString(interest.date) %
+                "','" % SKGServices::dateToSqlString(interest.valueDate) %
                 "','" % SKGServices::stringToSqlString(object.getRealTable() == QStringLiteral("operation") ? i18nc("Noun", "Relative to operation '%1'", SKGOperationObject(object).getDisplayName()) : i18nc("Noun", "Rate change")) %
                 "'," % SKGServices::doubleToString(interest.amount) %
                 ',' % SKGServices::doubleToString(interest.coef) %
@@ -813,13 +813,13 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
                 unit1.Value = SKGServices::stringToDouble(unitAccount.getAttribute(QStringLiteral("f_CURRENTAMOUNT")));
             }
         }
-        SKGTRACEL(5) << "iTargetBalance=" << doc->formatMoney(iTargetBalance, unit1, false) << Qt::endl;
+        SKGTRACEL(5) << "iTargetBalance=" << doc->formatMoney(iTargetBalance, unit1, false) << SKGENDL;
 
         // Get balance of checked operations
         QString balanceString;
         getDocument()->executeSingleSelectSqliteOrder("SELECT f_CHECKED from v_account_display WHERE id=" % SKGServices::intToString(getID()), balanceString);
         double balance = SKGServices::stringToDouble(balanceString);
-        SKGTRACEL(5) << "balance=" << doc->formatMoney(balance, unit1, false) << Qt::endl;
+        SKGTRACEL(5) << "balance=" << doc->formatMoney(balance, unit1, false) << SKGENDL;
 
 
         QString zero = doc->formatMoney(0, unit1, false);
@@ -828,7 +828,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
         if (sdiff == zero || sdiff == negativezero) {
             // This is an empty soluce
             output.push_back(QVector<SKGOperationObject>());
-            SKGTRACEL(5) << "empty solution found !!!" << Qt::endl;
+            SKGTRACEL(5) << "empty solution found !!!" << SKGENDL;
         } else {
             // Get all imported operation
             SKGObjectBase::SKGListSKGObjectBase operations;
@@ -847,7 +847,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
                 }
                 QString sdiff = doc->formatMoney(amount + balance - iTargetBalance * unit1.Value, unit1, false);
                 if (sdiff == zero || sdiff == negativezero) {
-                    SKGTRACEL(5) << "all operations are a solution !!!" << Qt::endl;
+                    SKGTRACEL(5) << "all operations are a solution !!!" << SKGENDL;
                     output.push_back(list);
                     return output;
                 }
@@ -855,9 +855,9 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
 
             // Search
             int nbmax = 500;
-            SKGTRACEL(5) << "Nb operations:" << nb << Qt::endl;
+            SKGTRACEL(5) << "Nb operations:" << nb << SKGENDL;
             if (nb > nbmax) {
-                SKGTRACEL(5) << "Too many operations (" << nb << ") ==> Reducing the size of the computation" << Qt::endl;
+                SKGTRACEL(5) << "Too many operations (" << nb << ") ==> Reducing the size of the computation" << SKGENDL;
                 for (int i = 0; i < nb - nbmax; ++i) {
                     SKGOperationObject op(operations.at(0));
                     auto amount = op.getCurrentAmount();
@@ -878,7 +878,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
     output.reserve(5);
     auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
     if (doc != nullptr) {
-        SKGTRACEL(5) << "iTargetBalance=" << doc->formatMoney(iTargetBalance, iUnit, false) << Qt::endl;
+        SKGTRACEL(5) << "iTargetBalance=" << doc->formatMoney(iTargetBalance, iUnit, false) << SKGENDL;
 
         // Comparison
         QString zero = doc->formatMoney(0, iUnit, false);
@@ -902,7 +902,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
 
             // Get all combination of operations
             int nbNext = nextOperations.count();
-            SKGTRACEL(5) << date << ":" << nbNext << " operations found" << Qt::endl;
+            SKGTRACEL(5) << date << ":" << nbNext << " operations found" << SKGENDL;
             std::vector<int> v(nbNext);
             for (int i = 0; i < nbNext; ++i) {
                 v[i] = i;
@@ -911,7 +911,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
             double nextBalance = iBalance;
             int index = 0;
             if (nbNext > 7) {
-                SKGTRACEL(5) << "Too many combination: " << factorial(nbNext) << " ==> limited to 5040" << Qt::endl;
+                SKGTRACEL(5) << "Too many combination: " << factorial(nbNext) << " ==> limited to 5040" << SKGENDL;
                 nbNext = 7;
             }
             nb = factorial(nbNext);
@@ -941,7 +941,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
                 // Test the combination
                 double diff = iBalance - iTargetBalance * iUnit.Value;
                 double previousDiff = diff;
-                SKGTRACEL(5) << "Check combination " << (index + 1) << "/" << nb << ": Diff=" << doc->formatMoney(diff, iUnit, false) << Qt::endl;
+                SKGTRACEL(5) << "Check combination " << (index + 1) << "/" << nb << ": Diff=" << doc->formatMoney(diff, iUnit, false) << SKGENDL;
 
                 // Try to find an immediate soluce
                 int nbop = combi.count();
@@ -952,18 +952,18 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
                         nextBalance += amount;
                     }
                     QString sdiff = doc->formatMoney(diff, iUnit, false);
-                    SKGTRACEL(5) << (j + 1) << "/" << nbop << ": Amount=" << amount << " / New diff=" << sdiff << Qt::endl;
+                    SKGTRACEL(5) << (j + 1) << "/" << nbop << ": Amount=" << amount << " / New diff=" << sdiff << SKGENDL;
                     if (sdiff == zero || sdiff == negativezero) {
                         // This is a soluce
                         auto s = combi.mid(0, j + 1);
                         if (output.contains(s)) {
-                            SKGTRACEL(5) << "found but already existing !!!" << Qt::endl;
+                            SKGTRACEL(5) << "found but already existing !!!" << SKGENDL;
                         } else {
                             output.push_back(s);
-                            SKGTRACEL(5) << "found !!!" << Qt::endl;
+                            SKGTRACEL(5) << "found !!!" << SKGENDL;
                             if (j == nbop - 1 || iSearchAllPossibleReconciliation) {
                                 // No need to test all combinations
-                                SKGTRACEL(5) << "No need to test all combinations" << Qt::endl;
+                                SKGTRACEL(5) << "No need to test all combinations" << SKGENDL;
                                 stopTests = true;
                             }
                         }
@@ -972,7 +972,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
 
                 // Check if tests of all combinations can be cancelled
                 if ((previousDiff > 0 && previousDiff + sumOperationsNegatives > 0) || (previousDiff < 0 && previousDiff + sumOperationPositives < 0)) {
-                    SKGTRACEL(5) << "No need to test all combinations due to signs of operations and diffs" << Qt::endl;
+                    SKGTRACEL(5) << "No need to test all combinations due to signs of operations and diffs" << SKGENDL;
                     stopTests = true;
                 }
 
@@ -991,9 +991,9 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
         }
     }
 
-    SKGTRACEL(5) << output.count() << " soluces found" << Qt::endl;
+    SKGTRACEL(5) << output.count() << " soluces found" << SKGENDL;
     if (!output.isEmpty()) {
-        SKGTRACEL(5) << "Size of the first soluce: " << output.at(0).count() << Qt::endl;
+        SKGTRACEL(5) << "Size of the first soluce: " << output.at(0).count() << SKGENDL;
     }
     return output;
 }
@@ -1024,7 +1024,7 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
         }
 
         // Check all
-        SKGTRACEL(5) << length << " operations pointed" << Qt::endl;
+        SKGTRACEL(5) << length << " operations pointed" << SKGENDL;
         for (int i = 0; i < length; ++i) {
             SKGOperationObject op(soluce.at(i));
             err = op.setStatus(SKGOperationObject::POINTED);
