@@ -244,7 +244,7 @@ SKGError SKGImportExportManager::getDefaultUnit(SKGUnitObject& oUnit, const QDat
         QString wc = QStringLiteral("t_type IN ('1', '2', 'C')");
         if (iDate != nullptr) {
             // Yes
-            wc += " AND (d_MINDATE<'" % SKGServices::dateToSqlString(iDate->startOfDay()) % "' OR d_MINDATE IS NULL)";
+            wc += " AND (d_MINDATE<'" % SKGServices::dateToSqlString(*iDate) % "' OR d_MINDATE IS NULL)";
         }
 
         // Check if a unit exist
@@ -337,9 +337,9 @@ SKGError SKGImportExportManager::finalizeImportation()
             if (!err && (nbOperations != 0)) {
                 err = m_document->sendMessage(i18np("One operation not imported because it already exists", "%1 operations not imported because they already exist", nbOperations), SKGDocument::Warning);
 
-                SKGTRACEL(1) << "### LIST OF OPERATIONS DELETED BY IMPORT_ID ###" << Qt::endl;
+                SKGTRACEL(1) << "### LIST OF OPERATIONS DELETED BY IMPORT_ID ###" << SKGENDL;
                 for (int i = 0; i < nbOperations; ++i) {
-                    SKGTRACEL(1) << objects.at(i).getDisplayName() << " " << objects.at(i).getAttribute(QStringLiteral("t_import_id")) << Qt::endl;
+                    SKGTRACEL(1) << objects.at(i).getDisplayName() << " " << objects.at(i).getAttribute(QStringLiteral("t_import_id")) << SKGENDL;
                 }
 
                 // Remove operations imported for nothing
@@ -358,9 +358,9 @@ SKGError SKGImportExportManager::finalizeImportation()
                 if (!err && (nbOperations2 != 0)) {
                     err = m_document->sendMessage(i18np("One operation was not imported because it was dated before the last imported one, you can uncheck the option to avoid this.", "%1 operations were not imported because they were dated before the last imported one, you can uncheck the option to avoid this.", nbOperations2), SKGDocument::Warning);
 
-                    SKGTRACEL(1) << "### LIST OF OPERATIONS DELETED BECAUSE AFTER THE LAST ONE ###" << Qt::endl;
+                    SKGTRACEL(1) << "### LIST OF OPERATIONS DELETED BECAUSE AFTER THE LAST ONE ###" << SKGENDL;
                     for (int i = 0; i < nbOperations2; ++i) {
-                        SKGTRACEL(1) << objects.at(i).getDisplayName() << Qt::endl;
+                        SKGTRACEL(1) << objects.at(i).getDisplayName() << SKGENDL;
                     }
 
                     // Remove operations imported for nothing
@@ -499,7 +499,7 @@ QString SKGImportExportManager::getImportMimeTypeFilter(bool iIncludingAll)
         KService::Ptr service = offers.at(i);
         QString name = service->name();
         QString msg = i18nc("Message", "Loading plugin %1/%2: %3...", i + 1, nb, name);
-        SKGTRACEL(1) << msg << Qt::endl;
+        SKGTRACEL(1) << msg << SKGENDL;
 
         KPluginLoader loader(service->library());
         KPluginFactory* factory = loader.factory();
@@ -550,7 +550,7 @@ QString SKGImportExportManager::getExportMimeTypeFilter(bool iIncludingAll)
         KService::Ptr service = offers.at(i);
         QString name = service->name();
         QString msg = i18nc("Message", "Loading plugin %1/%2: %3...", i + 1, nb, name);
-        SKGTRACEL(1) << msg << Qt::endl;
+        SKGTRACEL(1) << msg << SKGENDL;
 
         KPluginLoader loader(service->library());
         KPluginFactory* factory = loader.factory();
@@ -664,8 +664,8 @@ SKGError SKGImportExportManager::importFile()
                 // Import
                 fileTreated = true;
                 m_AccountToCheck.clear();
-                SKGTRACEL(2) << "Input filename=" << m_fileName.toDisplayString() << Qt::endl;
-                SKGTRACEL(2) << "Input local filename=" << getLocalFileName() << Qt::endl;
+                SKGTRACEL(2) << "Input filename=" << m_fileName.toDisplayString() << SKGENDL;
+                SKGTRACEL(2) << "Input local filename=" << getLocalFileName() << SKGENDL;
                 err = pluginInterface->importFile();
             }
 
@@ -695,8 +695,8 @@ SKGError SKGImportExportManager::exportFile()
             if (pluginInterface != nullptr) {
                 // Import
                 fileTreated = true;
-                SKGTRACEL(2) << "Input filename=" << m_fileName.toDisplayString() << Qt::endl;
-                SKGTRACEL(2) << "Input local filename=" << getLocalFileName(false) << Qt::endl;
+                SKGTRACEL(2) << "Input filename=" << m_fileName.toDisplayString() << SKGENDL;
+                SKGTRACEL(2) << "Input local filename=" << getLocalFileName(false) << SKGENDL;
                 err = pluginInterface->exportFile();
                 IFOKDO(err, SKGServices::upload(QUrl::fromLocalFile(getLocalFileName(false)), m_fileName))
             }
