@@ -67,7 +67,7 @@ double SKGInterestObject::getRate() const
 
 SKGError SKGInterestObject::setDate(QDate iDate)
 {
-    return setAttribute(QStringLiteral("d_date"), SKGServices::dateToSqlString(iDate.startOfDay()));
+    return setAttribute(QStringLiteral("d_date"), SKGServices::dateToSqlString(iDate));
 }
 
 QDate SKGInterestObject::getDate() const
