@@ -254,7 +254,7 @@ SKGError SKGOperationObject::setDate(QDate iDate, bool iRefreshSubOperations)
             }
         }
     }
-    IFOKDO(err, setAttribute(QStringLiteral("d_date"), SKGServices::dateToSqlString(iDate.startOfDay())))
+    IFOKDO(err, setAttribute(QStringLiteral("d_date"), SKGServices::dateToSqlString(iDate)))
     return err;
 }
 
