@@ -174,7 +174,7 @@ int SKGRecurrentOperationObject::getTimeLimit() const
 
 SKGError SKGRecurrentOperationObject::setDate(QDate iDate)
 {
-    return setAttribute(QStringLiteral("d_date"), SKGServices::dateToSqlString(iDate.startOfDay()));
+    return setAttribute(QStringLiteral("d_date"), SKGServices::dateToSqlString(iDate));
 }
 
 QDate SKGRecurrentOperationObject::getNextDate() const
