@@ -174,7 +174,7 @@ QVariantList SKGReportBank::getPortfolio()
 
                 // Get list of operations
                 SKGObjectBase::SKGListSKGObjectBase objs;
-                SKGError err = doc->getObjects(QStringLiteral("v_operation_display"), "d_date<'" % SKGServices::dateToSqlString(date.startOfDay()) % "' AND rc_unit_id IN (SELECT id FROM v_unit_display WHERE t_type='S' AND f_QUANTITYOWNED>0.01) ORDER BY t_UNIT", objs);
+                SKGError err = doc->getObjects(QStringLiteral("v_operation_display"), "d_date<'" % SKGServices::dateToSqlString(date) % "' AND rc_unit_id IN (SELECT id FROM v_unit_display WHERE t_type='S' AND f_QUANTITYOWNED>0.01) ORDER BY t_UNIT", objs);
                 int nb = objs.count();
                 if (!err && nb > 0) {
                     table.reserve(nb + 1);
